@@ -100,7 +100,7 @@ class DecisionTreeParam(BaseParam):
 
     criterion_params: list, should be non empty and first element is float-number, default: 0.1.
 
-    max_depth: int, positive integer, the max depth of a decision tree, default: 5
+    max_depth: int, positive integer, the max depth of a decision tree, default: 3
 
     min_sample_split: int, least quantity of nodes to split, default: 2
 
@@ -111,16 +111,11 @@ class DecisionTreeParam(BaseParam):
     max_split_nodes: int, positive integer, we will use no more than max_split_nodes to
                       parallel finding their splits in a batch, for memory consideration. default is 65536
 
-    n_iter_no_change: bool, accepted True,False only, if set to True, tol will use to consider
-                      stop tree growth. default: True
-
     feature_importance_type: str, support 'split', 'gain' only.
                              if is 'split', feature_importances calculate by feature split times,
                              if is 'gain', feature_importances calculate by feature split gain.
                              default: 'split'
 
-    tol: float, only use when n_iter_no_change is set to True, default: 0.001
-
     use_missing: bool, accepted True, False only, use missing value in training process or not. default: False
 
     zero_as_missing: bool, accepted True, False only, regard 0 as missing value or not,
@@ -128,8 +123,8 @@ class DecisionTreeParam(BaseParam):
 
     """
 
-    def __init__(self, criterion_method="xgboost", criterion_params=[0.1], max_depth=5,
-                 min_sample_split=2, min_imputiry_split=1e-3, min_leaf_node=1,
+    def __init__(self, criterion_method="xgboost", criterion_params=[0.1], max_depth=3,
+                 min_sample_split=2, min_impurity_split=1e-3, min_leaf_node=1,
                  max_split_nodes=consts.MAX_SPLIT_NODES, feature_importance_type="split",
                  n_iter_no_change=True, tol=0.001,
                  use_missing=False, zero_as_missing=False,):
@@ -138,7 +133,7 @@ class DecisionTreeParam(BaseParam):
         self.criterion_params = criterion_params
         self.max_depth = max_depth
         self.min_sample_split = min_sample_split
-        self.min_impurity_split = min_imputiry_split
+        self.min_impurity_split = min_impurity_split
         self.min_leaf_node = min_leaf_node
         self.max_split_nodes = max_split_nodes
         self.feature_importance_type = feature_importance_type
@@ -233,7 +228,7 @@ class BoostingParam(BaseParam):
 
     def __init__(self,  task_type=consts.CLASSIFICATION,
                  objective_param=ObjectiveParam(),
-                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1.0, n_iter_no_change=True,
+                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1, n_iter_no_change=True,
                  tol=0.0001, bin_num=32,
                  predict_param=PredictParam(), cv_param=CrossValidationParam(),
                  validation_freqs=None, metrics=None, subsample_random_seed=None,
@@ -316,7 +311,7 @@ class HeteroBoostingParam(BoostingParam):
 
     def __init__(self, task_type=consts.CLASSIFICATION,
                  objective_param=ObjectiveParam(),
-                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1.0, n_iter_no_change=True,
+                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1, n_iter_no_change=True,
                  tol=0.0001, encrypt_param=EncryptParam(),
                  bin_num=32,
                  encrypted_mode_calculator_param=EncryptedModeCalculatorParam(),
@@ -417,7 +412,7 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         complete_secure: bool, if use complete_secure, when use complete secure, build first tree using only guest
                         features
 
-        run_fast_histogram: bool, Available when encrypted method is 'iterativeAffine'
+        sparse_optimization: bool, Available when encrypted method is 'iterativeAffine'
                             An optimized mode for high-dimension, sparse data.
 
         """
@@ -457,7 +452,7 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         if type(self.zero_as_missing) != bool:
             raise ValueError('zero as missing should be bool type')
         self.check_boolean(self.complete_secure, 'complete_secure')
-        self.check_boolean(self.run_fast_histogram, 'run_fast_histogram')
+        self.check_boolean(self.sparse_optimization, 'sparse optimization')
 
         return True
 
@@ -466,14 +461,14 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
 
     def __init__(self, tree_param: DecisionTreeParam = DecisionTreeParam(), task_type=consts.CLASSIFICATION,
                  objective_param=ObjectiveParam(),
-                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1.0, n_iter_no_change=True,
+                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1, n_iter_no_change=True,
                  tol=0.0001, encrypt_param=EncryptParam(),
                  bin_num=32,
                  encrypted_mode_calculator_param=EncryptedModeCalculatorParam(),
                  predict_param=PredictParam(), cv_param=CrossValidationParam(),
-                 validation_freqs=None, early_stopping=None, use_missing=False, zero_as_missing=False,
+                 validation_freqs=None, early_stopping_rounds=None, use_missing=False, zero_as_missing=False,
                  complete_secure=False, tree_num_per_party=1, guest_depth=1, host_depth=1, work_mode='mix', metrics=None,
-                 subsample_random_seed=None, binning_error=consts.DEFAULT_RELATIVE_ERROR, sparse_optimization=False):
+                 sparse_optimization=False, subsample_random_seed=None, binning_error=consts.DEFAULT_RELATIVE_ERROR):
 
         """
         work_mode：
@@ -494,10 +489,11 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
         super(HeteroFastSecureBoostParam, self).__init__(tree_param, task_type, objective_param, learning_rate,
                                                          num_trees, subsample_feature_rate, n_iter_no_change, tol,
                                                          encrypt_param, bin_num, encrypted_mode_calculator_param,
-                                                         predict_param, cv_param, validation_freqs, early_stopping,
+                                                         predict_param, cv_param, validation_freqs, early_stopping_rounds,
                                                          use_missing, zero_as_missing, complete_secure, metrics=metrics,
                                                          subsample_random_seed=subsample_random_seed,
-                                                         binning_error=binning_error, sparse_optimization=sparse_optimization)
+                                                         sparse_optimization=sparse_optimization,
+                                                         binning_error=binning_error)
 
         self.tree_num_per_party = tree_num_per_party
         self.guest_depth = guest_depth
@@ -526,7 +522,7 @@ class HomoSecureBoostParam(BoostingParam):
 
     def __init__(self, tree_param: DecisionTreeParam = DecisionTreeParam(), task_type=consts.CLASSIFICATION,
                  objective_param=ObjectiveParam(),
-                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1.0, n_iter_no_change=True,
+                 learning_rate=0.3, num_trees=5, subsample_feature_rate=1, n_iter_no_change=True,
                  tol=0.0001, bin_num=32, predict_param=PredictParam(), cv_param=CrossValidationParam(),
                  validation_freqs=None, use_missing=False, zero_as_missing=False, subsample_random_seed=None,
                  binning_error=consts.DEFAULT_RELATIVE_ERROR
@@ -559,4 +555,3 @@ class HomoSecureBoostParam(BoostingParam):
         return True
 
 
-
